


{% block head %}

<title>Calculator</title>
<link rel="stylesheet" href="{{ url_for('static', filename='css/style.css') }}">
{% endblock %}

{% block body %}
<div class="content">
    <h1 style="text-align: center">Calculator</h1>

    <div class="form">
        <form action="/math" method="POST">
            <label for="operation">Choose a Mathematical Operation</label>

<select id="operation" name="operation">
  <option value="add">add</option>
  <option value="subtract">subtract</option>
  <option value="multiply">multiply</option>
  <option value="divide">divide</option>
</select>
            <input type="text" name="num1" id="num1">
            <input type="text" name="num2" id="num2">
            <input type="submit" value="Calculate">
        </form>
    </div>
</div>
{% endblock %}